LocationAlreadyInitializedException class

Thrown when attempting to initialize the plugin multiple times.

The plugin uses a singleton pattern and can only be initialized once. Call dispose before re-initializing if needed.

Inheritance

Constructors

LocationAlreadyInitializedException({String message = 'Live location plugin already initialized'})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited