LocationConfigurationException class

Thrown when invalid configuration is provided.

Check that all required configuration parameters are valid.

Inheritance

Constructors

LocationConfigurationException({required String message})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited