LocationInitializationException class

Thrown when plugin initialization fails.

This may indicate invalid configuration, native platform error, or double initialization attempt.

Inheritance

Constructors

LocationInitializationException({String message = 'Failed to initialize live location plugin'})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited