LocationNotInitializedException class

Thrown when an operation is attempted before initialization.

Call LiveLocation.initialize first.

Inheritance

Constructors

LocationNotInitializedException({String message = 'Live location plugin not initialized'})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited