LocationPermissionException class

Thrown when required location permission is not granted.

User should grant the permission in app settings or via permission dialog.

Inheritance

Constructors

LocationPermissionException({String message = 'Location permission not granted'})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited