LocationPlatformException class

Thrown when platform channel communication fails.

This indicates a native platform error or communication breakdown.

Inheritance

Constructors

LocationPlatformException({required String message, String? code})

Properties

code String?
The platform-specific error code
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited