LocationServiceDisabledException class

Thrown when location services are not available or disabled on the device.

User should enable location services in device settings.

Inheritance

Constructors

LocationServiceDisabledException({String message = 'Location services are disabled'})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited