checkPermission method
Returns the current location permission status without prompting the user.
Implementation
Future<LocationPermissionStatus> checkPermission() async {
throw UnimplementedError('checkPermission() has not been implemented.');
}
Returns the current location permission status without prompting the user.
Future<LocationPermissionStatus> checkPermission() async {
throw UnimplementedError('checkPermission() has not been implemented.');
}