LocationAccuracy enum

Location accuracy levels for GPS updates.

Higher accuracy levels consume more battery but provide more precise locations.

Inheritance
Available extensions

Values

lowest → const LocationAccuracy

~3500m accuracy, low battery consumption

low → const LocationAccuracy

~500m accuracy, moderate battery consumption

medium → const LocationAccuracy

~100m accuracy, balanced battery consumption

high → const LocationAccuracy

~5-50m accuracy, high battery consumption

best → const LocationAccuracy

~0-5m accuracy, very high battery consumption

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LocationAccuracy>
A constant List of the values in this enum, in order of their declaration.