PermissionStatus enum

Permission status for location access.

Inheritance
Available extensions

Values

notRequested → const PermissionStatus

Permission not yet requested from user

whileInUse → const PermissionStatus

Permission granted for location access while app is in use

always → const PermissionStatus

Permission granted for location access always (foreground and background)

denied → const PermissionStatus

Permission denied by user

restricted → const PermissionStatus

Permission restricted (OS level, e.g., parental controls)

unknown → const PermissionStatus

Permission status cannot be determined

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PermissionStatus>
A constant List of the values in this enum, in order of their declaration.