LocationAlreadyInitializedException class
Thrown when attempting to initialize the plugin multiple times.
The plugin uses a singleton pattern and can only be initialized once.
Call dispose before re-initializing if needed.
- Inheritance
-
- Object
- LocationException
- LocationAlreadyInitializedException
Constructors
- LocationAlreadyInitializedException({String message = 'Live location plugin already initialized'})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited