LocationInitTimeoutException class
Thrown when the location provider does not become ready within the timeout.
Most commonly occurs on emulators without GPS hardware, or devices where location services are unresponsive. Ensure location services are enabled and the device has GPS hardware.
- Inheritance
-
- Object
- LocationException
- LocationInitTimeoutException
Constructors
- LocationInitTimeoutException({String message = 'Location provider initialization timed out. ' 'Ensure the device has GPS hardware and location services are enabled.'})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited