LocationPlatformException class
Thrown when platform channel communication fails.
This indicates a native platform error or communication breakdown.
- Inheritance
-
- Object
- LocationException
- LocationPlatformException
Constructors
- LocationPlatformException({required String message, String? code})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited