LocationServiceDisabledException class
Thrown when location services are not available or disabled on the device.
User should enable location services in device settings.
- Inheritance
-
- Object
- LocationException
- LocationServiceDisabledException
Constructors
- LocationServiceDisabledException({String message = 'Location services are disabled'})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited