onStreamCancelled method

void onStreamCancelled()

Called when all listeners unsubscribe from the location stream.

Used to optimize battery by stopping updates when not needed.

Implementation

void onStreamCancelled() {
  throw UnimplementedError('onStreamCancelled() has not been implemented.');
}